@@ -16,7 +16,8 @@
  */
 package org.apache.commons.rng.sampling.distribution;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Assertions;
 import org.apache.commons.rng.UniformRandomProvider;
 import org.apache.commons.rng.sampling.RandomAssert;
 import org.apache.commons.rng.simple.RandomSource;
@@ -24,10 +25,10 @@ import org.apache.commons.rng.simple.RandomSource;
 /**
  * Test for {@link ZigguratNormalizedGaussianSampler}.
  */
-public class ZigguratNormalizedGaussianSamplerTest {
+class ZigguratNormalizedGaussianSamplerTest {
     // Cf. RNG-56
-    @Test(expected = StackOverflowError.class)
-    public void testInfiniteLoop() {
+    @Test
+    void testInfiniteLoop() {
         // A bad implementation whose only purpose is to force access
         // to the rarest branch.
         final UniformRandomProvider bad = new UniformRandomProvider() {
@@ -45,16 +46,17 @@ public class ZigguratNormalizedGaussianSamplerTest {
             };
 
         // Infinite loop (in v1.1).
-        new ZigguratNormalizedGaussianSampler(bad).sample();
+        Assertions.assertThrows(StackOverflowError.class,
+            () -> new ZigguratNormalizedGaussianSampler(bad).sample());
     }
 
     /**
      * Test the SharedStateSampler implementation.
      */
     @Test
-    public void testSharedStateSampler() {
-        final UniformRandomProvider rng1 = RandomSource.create(RandomSource.SPLIT_MIX_64, 0L);
-        final UniformRandomProvider rng2 = RandomSource.create(RandomSource.SPLIT_MIX_64, 0L);
+    void testSharedStateSampler() {
+        final UniformRandomProvider rng1 = RandomSource.SPLIT_MIX_64.create(0L);
+        final UniformRandomProvider rng2 = RandomSource.SPLIT_MIX_64.create(0L);
         final SharedStateContinuousSampler sampler1 =
             ZigguratNormalizedGaussianSampler.<ZigguratNormalizedGaussianSampler>of(rng1);
         final SharedStateContinuousSampler sampler2 = sampler1.withUniformRandomProvider(rng2);
